******************************************************************************
*** Stata Syntax for computing migration trends from MAFE household data *****
*** B. Schoumaker and C. Beauchemin - March 2015 *****************************
******************************************************************************


** seed for random numbers (used in imputation) is fixed

set seed 100


***************************************************************************************
*** DEFINITIONS OF FILES, COUNTRY, ETC. ***********************************************
*** Comments starting in UPPER CASE indicate the user needs to CHANGE a local macro ***
***************************************************************************************

** Several local macros can be changed
** here are the values of the macros corresponding to the models in Appendix Table 11 of the Paper

** Model W3H-1 : local dest 1 2 3 4 / local defper 1 / local death 0 
** Model A3H-1 : local dest 3  / local defper 1 / local death 0 
** Model E3H-1 : local dest 1  / local defper 1 / local death 0 
** Model O3H-1 : local dest 2 4  / local defper 1 / local death 0 

** Model W7H-1 : local dest 1 2 3 4 / local defper 2 / local death 0 
** Model A7H-1 : local dest 3 / local defper 2 / local death 0 
** Model E7H-1 : local dest 1 / local defper 2 / local death 0 
** Model O7H-1 : local dest 2 4 / local defper 2 / local death 0 

** Model W3H-2 : local dest 1 2 3 4 / local defper 1 / local death 1 



* CHANGE the code depending on which country you work
* country code (99312:DR CONGO; 99341:Senegal; 99329:Ghana)

local pays 99312

* CHOOSE destinations (1=Europe 2=Asia and others 3=Africa 4=North America)
* eg. Europe only -> local dest 1
* eg. All destinations-> local dest 1 2 3 4

local dest 1 2 3 4

* SELECT whether deceased people are included or not in the estimates
* local death 1 if deceased people are used; local death 0 otherwise
local death 0


* CHOOSE for periods for reconstructing migration trends
* 1=3 broad periods, 2=5-year periods, 3= yearly estimates

local defper 1

if `defper'==1 {
local timeper (1975/1989=1) (1990/1999=2) (2000/2008=3)
}

if `defper'==2 {
local timeper (1975/1979=1) (1980/1984=2) (1985/1989=3) (1990/1994=4) (1995/1999=5) (2000/2004=6) (2005/2009=7)
}

if `defper'==3 {
forval i=1975/2008 {
local a=`a'+1
local timeper "`timeper' (`i'/`i'=`a')"
}
}


* numer of periods is counted for predicted values
local nper=wordcount("`timeper'")


* CHOOSE version of data file (the six figures correspond to the date of the version of the file)
* Example local date 131403
* for this program - files were renamed with Suffix DemRes

local date DemRes

* Automatic  adaptations of some variables to countries
* last year (year survey -1) : 2008 for DRC and GHANA, 2007 For Senegal
* name and directory for files	
* name of relationship variable
* USERS will have to change the directories where data files are located

if `pays'==99341{
	local ysurv=2007
	local name sn
	local relat a3
	global In "C:\12.DATA\MAFE\Senegal\Household\"

}

if `pays'==99312{
	local ysurv=2008
	local name rdc
	local relat a3_1
	global In "C:\12.DATA\MAFE\DRC\Household\"
	
	if (`dest'==3 & `defper'==2) {
		local ifmod if periodG>1  // for models from DR Congo to Africa by 5-year period, drops first period because estimation problems-1
	}
}

if `pays'==99329{ 
	local ysurv=2008
	local name gh
	local relat a3_1
	global In "C:\12.DATA\MAFE\Ghana\Household\"
}



*** definition of the risk set : children of head of househod (a3==4)
*** if deceased children are included: : keep children wose age at death (a2_age ) not missing

local selection if `relat'==4


if `death'==1 {
local selection if `relat'==4 | a2_age!=.
}


* define minimum age for computing migration probabilities. If probabilities start at 18, define agemin as 18.

local agemin 18
local agelow=`agemin'-1


***************************************
***** DATA PREPARATION ****************
***************************************

*** the name of the data file as adapted depending on the country and version of the file
*** the data file is opened


use "$In\`name'_qm_indiv_`date'.dta", clear
save "$In\`name'_qm_indiv_`date'_workingfile.dta", replace


*** selection of variables needed for the models

keep ident q3* `relat' a12 a13* a1 a13b weight_hhd a11 a14p a18 a4 a2*

*** Imputation of missing values for age 

gene age=q3age
replace age=`ysurv'-q3annee if age==. & q3annee!=9999

gene age_imp=age
forvalues x=1/5 {
set seed `x'
cap drop rnum
gene rnum=int(uniform()*_N)
replace age_imp=age[rnum] if age_imp==9999 |age_imp==. 
}

* computation of year of birth *

gene yearb=q3annee
replace yearb=`ysurv'-age_imp if q3annee==8888 | q3annee==9999 | q3annee==.


*** Definition of the risk set

keep `selection'

*** Identification of migrants

drop if a14pays != `pays' //Removes people born out of country of origin
drop if a12==2 // drop people who have lived all their lives abroad


*** drop inconsistent cases (people abroad declared as never lived abroad (no date of departure)

gene abroad=cond(a11!=.,1,0) // currently abroad
gene ever=cond(a12==3, 1, 0) // ever lived abroad
gene return=ever-abroad // return (ever-current)

drop if return<0
drop if a12==.c | a12==.b


*** replace missing values for age/year of first departure *
*** year of first departure (yeardep)

gene yeardep=a13a_an
replace yeardep=yearb+a13a_age if (a13a_age!=. & a13a_age!=0 & a13a_age!=8888 & a13a_age!=9999) & (a13a_an==. & a13a_an==0 & a13a_an==8888 & a13a_an==9999)
replace yeardep=.c if (yeardep==0) & a12==3


**** Creation of migration and duration variables

gene dest=int(a13b/100) // destination by broad regions
recode dest (960=1) (991=1) (992=2) (993=3) (994=4) (995=2)(88=9) (99=9) (.=.) // recode destination
label define dest 1 "Europe" 2 "Asia and others" 3 "Africa" 4 "North America" 9 "Missing", replace
label val dest dest


*** defines duration variable

gene timevar=yeardep
replace timevar=`ysurv' if yeardep==. 	// censoring at date of survey if no migrayion

if `death'==1 { 						// censoring at year of death for deceased people
replace timevar=a2_age+q3annee if a2_age!=.
}


** date at entry into risk set

gene date17=yearb+`agelow'


******************************************
**** Declaration of survival data (stset)*
******************************************

local exit `ysurv'+1

*clock starts ticking at date17 (when individual turns 18)
*local macro dest is used to identify destination

stset timevar, id(ident) failure(dest=`dest') origin(date17) exit(time `exit')

drop if _st==0 // keep observation with _st==1
stsplit year, every(1) after(1965) // split observations per year
drop if timevar<1975 |timevar>`ysurv' //  start of observation window end 1974


*** define age and age groups
gene agetv=timevar-yearb // age equal as running year minus year of birth
recode agetv (0/17=0) (18/24=1) (25/39=2) (40/100=3), gene(agebg) // recode age
label define agebg 1 "18-24" 2 "25-39" 3 "40 and over", replace
label val agebg agebg


** selection of people between 18 and 40 (exact ages)
drop if agetv<18 | agetv>39


** definition of time periods using the local macro (3 periods, 5-year periods or yearly estimates)
recode timevar `timeper', gene(periodG)


************************************************************
*** Estimation of discrete-time event-history model model **
************************************************************

*char periodG[omit] 2

xi: logit _d i.agebg i.periodG [pw=weight_hhd] `ifmod' // ifmod selects periodg>1 for models from DR Congo to Africa for 5-year periods because estimation issue


estimate stats // computes AIC and BIC


** count individuals

by ident, sort: gene ind=1 if _n==1
tab ind


*********************************************************************
*** Cumulative probabilities and confidence intervals (Delta method)
**********************************************************************

*** create formulas for cumulative probabilities from regression coefficient

* first period
local Period1 1-((1-exp(_b[_cons])/(1+exp(_b[_cons])))^7*(1-exp(_b[_cons]+_b[ _Iagebg_2])/(1+exp(_b[_cons]+_b[ _Iagebg_2])))^15) // 1-products of survival probabilites from 18-25 and 25-40


* next periods
forval i=2/`nper' {
local Period`i' 1-((1-exp(_b[_cons]+_b[_IperiodG_`i'])/(1+exp(_b[_cons]+_b[_IperiodG_`i'])))^7*(1-exp(_b[_cons]+_b[ _Iagebg_2]+_b[_IperiodG_`i'])/(1+exp(_b[_cons]+_b[ _Iagebg_2]+_b[_IperiodG_`i'])))^15)
}


*** creates a macro with the formulas for all the periods
*   removes first period for DR Congo to Africa by 5-year periods

local start=1
if "`ifmod'"!="" {
local start=2
}


forval i=`start'/`nper' {
local P`i' (Period`i': "`Period`i''")  
local Pfull "`Pfull' `P`i''"
}

*** computes predicted cumulative probabilities and 90% confidennce intervales


di "Predicted cumulative probabilities of migration (18-40) and 90% Confidence intervals"
di "destinations:" `dest'
di "origin:" "`name'"

nlcom `Pfull', level(90) iterate(100)




**** End of the syntax

