******************************************************************************
*** Stata Syntax for computing migration trends from MAFE network data *******
*** B. Schoumaker and C. Beauchemin - March 2015 *****************************
******************************************************************************

***************************************************************************************
*** DEFINITIONS OF FILES, COUNTRY, ETC. ***********************************************
*** Comments starting in UPPER CASE indicate the user needs to CHANGE a local macro ***
***************************************************************************************

** Several local macros can be changed
** here are the values of the macros corresponding to the models in Appendix Table 11 of the Paper

** Model W3N-1-1-1 : local dest 1 2 3 4 / local defper 1 / local death 0 / local mtype 1
** Model W3N-1-2-1 : local dest 1 2 3 4 / local defper 1 / local death 0 / local mtype -1
** Model E3N-1-1-1 : local dest 1 / local defper 1 / local death 0 / local mtype 1
** Model E3N-1-1-2 : local dest 1 / local defper 1 / local death 0 / local mtype 0
** Model E3N-2-2-2 : local dest 1 / local defper 1 / local death 1 / local mtype -2


* CHANGE the code depending on which country you work
* country code (99312:DR CONGO; 99341:Senegal; 99329:Ghana)

local code_pays 99312


** Automatic adaptation by country
** date may need to be changed (suffix of the file with date of the file. Here, suffix DemRes is used).

if `code_pays'==99341 {
	local ysurv 2007
	local cn sn_
	*local date _120116
	local ctr SENEGAL
	local pays "Sn"
	local sdate 1990
	global In "C:\12.DATA\MAFE\Senegal\Biographic\"
}


if `code_pays'==99312 {
	local ysurv 2008
	local cn rdc_
	*local date _120209
	local date _DemRes
	local ctr DRC
	local pays "C"
	local sdate 1991
	global In "C:\12.DATA\MAFE\DRC\Biographic\"
}

if `code_pays'==99329 {

	local ysurv 2008
	local cn gh_
	*local date _120127
	local ctr GHANA
	local pays "G"
	local sdate 1991
	global In "C:\12.DATA\MAFE\Ghana\Biographic\"
}


* CHOOSE for periods for reconstructing migration trends
* 1=3 broad periods, 2=5-year periods, 3= yearly estimates

local defper 1

if `defper'==1 {
	local timeper (1975/1989=1) (1990/1999=2) (2000/2008=3)
}

if `defper'==2 {
	local timeper (1975/1979=1) (1980/1984=2) (1985/1989=3) (1990/1994=4) (1995/1999=5) (2000/2004=6) (2005/2009=7)
}

if `defper'==3 {
	forval i=1975/2008 {
		local a=`a'+1
		local timeper "`timeper' (`i'/`i'=`a')"
	}
}


* numer of periods is counted for predicted values
local nper=wordcount("`timeper'")



* SELECT whether deceased people are included or not in the estimates
* local death 1 if deceased people are used; local death 0 otherwise
local death 1



**************************************
*** CHARACTERISTICS OF MODELS 
**************************************

*for baseline network model : death 0, mtype 1, dest 1 2 3 4, agemin 18
*for model with filtering effect of age : death 0, mtype -1, dest 1 2 3 4, agemin 18
*for model with filtering effect of destination (Europe) - Figure 12: death 0, mtype 0, dest 1, agemin 18, dest2 1
	*** to compare to : death 0, mtype 1, dest 1, agemin 18, dest2 1
*for model with all relaxed (Europe) - death 1, mtype -2, dest 1, agemin 18, dest2 1

	
** CHOOSE the type of model (mtype)
	
	
** mtype -2 -> pas de filtering 18 ans ni par destination
** mtype -1 -> pas de filtering 18 ans
** mtype 1 -> comme donnes mnage
** mtype 0 -  utiliser pour filtre par destination (0=pas de filtre par destination)

local mtype -2


** SELECT the destinations
** Selection of destinations as events : selected destinations are events, others are censored cases
** all destinations : local dest 1 2 3 4; only Europe : local des 1; only Africa : local dest 3; others : local dest 2 4 
local dest 1

** dest2 is automatically set to dest if mtype=0 or -2 and dest=1

if (`mtype'==-2 | `mtype'==0) {
	local dest2=`dest' 
}


* DEFINE minimum age for computing migration probabilities. If probabilities start at 18, define agemin as 18.

local agemin 18
local agelow=`agemin'-1


*** make a file of birth dates of all children

use "$In\`cn'qb_children`date'.dta", clear

** keep only respondents living in origin country (those in Europe are dropped)
keep if id_c=="`pays'"

*removes duplicates if any
duplicates drop

** keep selection of variables
keep ident num_enf q201n q201d weight_all q205

*keep children aged 18 and over
gene keep=1 if q201n<=`sdate'

* sort for merging
sort ident num_enf
save "$In\children.dta", replace

*** Open network data file

use "$In\`cn'qb_network`date'.dta", clear
drop weight_all
by ident (q904d), sort : replace num_mig=_n

* recode links to ego
recode q901 (1=1) (2=2) (3=3) (4=4) (5/13=5) (14=6) (15=7), gene(lien)

** keep only respondents living in origin country (those in Europe are dropped)
keep if id_c=="`pays'"


* keep only children of ego
keep if q901==2

* rename chilren identifier 
gene num_enf=q901e
destring num_enf, replace

*sort before merging
sort ident num_enf

merge m:1 ident num_enf using "$In\children.dta"

** The "using only" are children who have NOT migrated
** The "matched" are children who HAVE migrated


* keep only children born in origin country
keep if q205==`code_pays'

* if only surviving children are included, keep only thos with missing date of death (alive)
if `death'==0 {
		keep if q201d==.
}


* New identifier combining ego's ioent and child number for a children file

egen childid=group(ident num_enf)


** recod destination

gene dest=int(country/100) // destination by broad regions
recode dest (960=1) (991=1) (992=2) (993=3) (994=4) (995=4)(88=9) (99=9) (.=.)

label define dest 1 "Europe" 2 "Asia and others" 3 "Africa" 4 "North America" 9 "Missing", replace
label val dest dest



**************************************************
**** Creation of migration and duration variables*
**************************************************


*** Automatic Adaptations depending on model type


if `mtype'==-2 {


	* Keep first migration to Europe, and do as if previous migration to other destinations had not occurred
	* replaces date of departure by missing value if destination other than Europe 
	* keep first migration after age 18 and do as if other migration had not occurred 

	replace q904d=. if dest!=`dest2'
	replace q904d=. if q904d-q201n<18
	by ident num_enf (q904d), sort : gene keep2=1 if _n==1
	keep if keep2==1

}


if `mtype'==0 {


	* Keep first migration to selected destination (e.g. Europe) and do as if other migrations had not occured
	* Departure date is replaced by missing if not to selected destination (e.g. Europe)

	replace q904d=. if dest!=`dest2'
	by ident num_enf (q904d), sort : gene keep2=1 if _n==1
	keep if keep2==1
}


if `mtype'==-1 {

	* Keep first migration from 18 and do as if previous migration had not occured
	* Departure date is replaced by missing if migration before 18

	replace q904d=. if q904d-q201n<18
	by ident num_enf (q904d), sort : gene keep2=1 if _n==1
	keep if keep2==1
	}




if `mtype'==1 {

	* first keep the first migration and use the same program as with houshold data
		by ident num_enf (q904d), sort : gene keep2=1 if _n==1
		keep if keep2==1
}

** Duration variable

gene timevar=q904d
replace timevar=`ysurv' if q904d==.

*** if deceased children are included: : keep children wose date of death not missing

if `death'==0 {
	keep if q201d==.
}


if `death'==1 {
	replace timevar=q201d if q201d!=.
}


** date at entry into risk set

gene date17=q201n+`agelow'


******************************************
**** Declaration of survival data (stset)*
******************************************

local exit `ysurv'+1

*clock starts ticking at date17 (when individual turns 18)
*local macro dest is used to identify destination


stset timevar, id(childid) failure(dest=`dest') origin(date17) exit(time `exit')

drop if _st==0 //keep observation with _st==1
stsplit year, every(1) after(1965) // split observations per year
drop if timevar<1975 |timevar>`ysurv' // start of observation window end 1974


*** age groups
gene agetv=timevar-q201n
recode agetv (0/17=0) (18/24=1) (25/39=2) (40/100=3), gene(agebg)
label define agebg 1 "18-24" 2 "25-39" 3 "40 and over", replace
label val agebg agebg


** selection of people between 18 and 40 (exact ages)
drop if agetv<18 | agetv>39

*drop if agetv<18 


** definition of time periods using the local macro (3 periods, 5-year periods or yearly estimates)
recode timevar `timeper', gene(periodG)


xi: logit _d i.agebg i.periodG [pw=weight_all]


** AIC and BIC
estimate stats

** count individuals
by childid, sort: gene ind=1 if _n==1
tab ind

*********************************************************************
*** Cumulative probabilities and confidence intervals (Delta method)
**********************************************************************

*** create formulas for cumulative probabilities

local nper 3

* first period
local Period1 1-((1-exp(_b[_cons])/(1+exp(_b[_cons])))^7*(1-exp(_b[_cons]+_b[ _Iagebg_2])/(1+exp(_b[_cons]+_b[ _Iagebg_2])))^15)


* next periods
forval i=2/`nper' {
	local Period`i' 1-((1-exp(_b[_cons]+_b[_IperiodG_`i'])/(1+exp(_b[_cons]+_b[_IperiodG_`i'])))^7*(1-exp(_b[_cons]+_b[ _Iagebg_2]+_b[_IperiodG_`i'])/(1+exp(_b[_cons]+_b[ _Iagebg_2]+_b[_IperiodG_`i'])))^15)
}


forval i=1/`nper' {
	local P`i' (Period`i': "`Period`i''")  
	local Pfull "`Pfull' `P`i''"
	}


di "NETWORK DATA"
di "Predicted cumulative probabilities of migration (18-40) and 90% Confidence intervals"
di "destinations:" `dest'
di "origin:" "`ctr'"

nlcom `Pfull', level(90)

